==> openshift-model-monitoring-5.4.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RemoteWriteSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RemoteWriteSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec,io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecBuilder> {

    io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public RemoteWriteSpecBuilder() {
        this(true);
    }

    public RemoteWriteSpecBuilder(java.lang.Boolean validationEnabled) {
        this(new RemoteWriteSpec(), validationEnabled);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new RemoteWriteSpec(), validationEnabled);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec instance) {
        this(fluent, instance, true);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withBasicAuth(instance.getBasicAuth()); 
        fluent.withBearerToken(instance.getBearerToken()); 
        fluent.withBearerTokenFile(instance.getBearerTokenFile()); 
        fluent.withName(instance.getName()); 
        fluent.withProxyUrl(instance.getProxyUrl()); 
        fluent.withQueueConfig(instance.getQueueConfig()); 
        fluent.withRemoteTimeout(instance.getRemoteTimeout()); 
        fluent.withTlsConfig(instance.getTlsConfig()); 
        fluent.withUrl(instance.getUrl()); 
        fluent.withWriteRelabelConfigs(instance.getWriteRelabelConfigs()); 
        this.validationEnabled = validationEnabled; 
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec instance) {
        this(instance,true);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withBasicAuth(instance.getBasicAuth()); 
        this.withBearerToken(instance.getBearerToken()); 
        this.withBearerTokenFile(instance.getBearerTokenFile()); 
        this.withName(instance.getName()); 
        this.withProxyUrl(instance.getProxyUrl()); 
        this.withQueueConfig(instance.getQueueConfig()); 
        this.withRemoteTimeout(instance.getRemoteTimeout()); 
        this.withTlsConfig(instance.getTlsConfig()); 
        this.withUrl(instance.getUrl()); 
        this.withWriteRelabelConfigs(instance.getWriteRelabelConfigs()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec build() {
        RemoteWriteSpec buildable = new RemoteWriteSpec(fluent.getBasicAuth(),fluent.getBearerToken(),fluent.getBearerTokenFile(),fluent.getName(),fluent.getProxyUrl(),fluent.getQueueConfig(),fluent.getRemoteTimeout(),fluent.getTlsConfig(),fluent.getUrl(),fluent.getWriteRelabelConfigs());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RemoteWriteSpecBuilder that = (RemoteWriteSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-monitoring-5.7.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RemoteWriteSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RemoteWriteSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec,io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecBuilder> {

    io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public RemoteWriteSpecBuilder() {
        this(true);
    }

    public RemoteWriteSpecBuilder(java.lang.Boolean validationEnabled) {
        this(new RemoteWriteSpec(), validationEnabled);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new RemoteWriteSpec(), validationEnabled);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec instance) {
        this(fluent, instance, true);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withBasicAuth(instance.getBasicAuth()); 
        fluent.withBearerToken(instance.getBearerToken()); 
        fluent.withBearerTokenFile(instance.getBearerTokenFile()); 
        fluent.withHeaders(instance.getHeaders()); 
        fluent.withMetadataConfig(instance.getMetadataConfig()); 
        fluent.withName(instance.getName()); 
        fluent.withProxyUrl(instance.getProxyUrl()); 
        fluent.withQueueConfig(instance.getQueueConfig()); 
        fluent.withRemoteTimeout(instance.getRemoteTimeout()); 
        fluent.withTlsConfig(instance.getTlsConfig()); 
        fluent.withUrl(instance.getUrl()); 
        fluent.withWriteRelabelConfigs(instance.getWriteRelabelConfigs()); 
        this.validationEnabled = validationEnabled; 
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec instance) {
        this(instance,true);
    }

    public RemoteWriteSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withBasicAuth(instance.getBasicAuth()); 
        this.withBearerToken(instance.getBearerToken()); 
        this.withBearerTokenFile(instance.getBearerTokenFile()); 
        this.withHeaders(instance.getHeaders()); 
        this.withMetadataConfig(instance.getMetadataConfig()); 
        this.withName(instance.getName()); 
        this.withProxyUrl(instance.getProxyUrl()); 
        this.withQueueConfig(instance.getQueueConfig()); 
        this.withRemoteTimeout(instance.getRemoteTimeout()); 
        this.withTlsConfig(instance.getTlsConfig()); 
        this.withUrl(instance.getUrl()); 
        this.withWriteRelabelConfigs(instance.getWriteRelabelConfigs()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.openshift.api.model.monitoring.v1.RemoteWriteSpec build() {
        RemoteWriteSpec buildable = new RemoteWriteSpec(fluent.getBasicAuth(),fluent.getBearerToken(),fluent.getBearerTokenFile(),fluent.getHeaders(),fluent.getMetadataConfig(),fluent.getName(),fluent.getProxyUrl(),fluent.getQueueConfig(),fluent.getRemoteTimeout(),fluent.getTlsConfig(),fluent.getUrl(),fluent.getWriteRelabelConfigs());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RemoteWriteSpecBuilder that = (RemoteWriteSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
